@@ -55,6 +55,12 @@ class CreateElasticityAssuranceRequest(RpcRequest):
 	def set_StartTime(self,StartTime):
 		self.add_query_param('StartTime',StartTime)
 
+	def get_ResourceGroupId(self):
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self,ResourceGroupId):
+		self.add_query_param('ResourceGroupId',ResourceGroupId)
+
 	def get_PrivatePoolOptionsMatchCriteria(self):
 		return self.get_query_params().get('PrivatePoolOptions.MatchCriteria')
 
@@ -69,6 +75,16 @@ class CreateElasticityAssuranceRequest(RpcRequest):
 			if InstanceTypes[depth1] is not None:
 				self.add_query_param('InstanceType.' + str(depth1 + 1) , InstanceTypes[depth1])
 
+	def get_Tags(self):
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tags):
+		for depth1 in range(len(Tags)):
+			if Tags[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tags[depth1].get('Key'))
+			if Tags[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tags[depth1].get('Value'))
+
 	def get_Period(self):
 		return self.get_query_params().get('Period')
 
